@@ -19,6 +19,8 @@
 
 #include <gtk/gtk.h>
 #include <hildon/hildon.h>
+#include <time.h>
+#include <clockd/libtime.h>
 #include <libosso-abook/osso-abook.h>
 #include <libosso-abook/osso-abook-roster.h>
 #include <libosso-abook/osso-abook-roster-manager.h>
@@ -42,6 +44,9 @@
 #define NOTIFIER_NOTIFY_STATUS_MESSAGE_GCONF_PATH GC_ROOT "/status_message"
 #define NOTIFIER_AUTO_CLOSE_TIME_GCONF_PATH GC_ROOT "/notification_timeout"
 #define NOTIFIER_AUTO_CLOSE_NOTIFICATION_GCONF_PATH GC_ROOT "/auto_notification_close"
+#define NOTIFIER_HIDE_NOTIFICATION_GCONF_PATH GC_ROOT "/hide_notification"
+#define NOTIFIER_LOG_NOTIFICATION_GCONF_PATH GC_ROOT "/log_notification"
+#define NOTIFIER_LOGFILE_PATH_GCONF_PATH GC_ROOT "/logfile_path"
 
 struct _PresenceNotifierStatusPluginPrivate
 {
@@ -55,6 +60,9 @@ struct _PresenceNotifierStatusPluginPrivate
   OssoABookAggregator* abook_aggregator;
   OssoABookAccountManager* abook_account_manager;
   DBusGConnection* dbus_connection;
+  gboolean hide_notification;
+  gboolean log_notification;
+  gchar* logfile_path;
 };
 
 typedef struct _presence_data_t
@@ -89,6 +97,28 @@ static void presence_data_free(presence_data_t* data)
   g_free(data);
 }
 
+static void
+_log_presence_message(PresenceNotifierStatusPlugin* plugin,
+		       OssoABookPresence* presence)
+{
+  if(plugin->priv->logfile_path)
+  {
+    const char* status_message = osso_abook_presence_get_presence_status_message(presence);
+    if(!status_message)
+      status_message = osso_abook_presence_get_display_status(presence);
+    
+    const gchar* contact_name = osso_abook_contact_get_name(OSSO_ABOOK_CONTACT(presence));
+    const gchar* display_name = osso_abook_contact_get_bound_name(OSSO_ABOOK_CONTACT(presence));
+    FILE *f = fopen(plugin->priv->logfile_path,"at");
+    struct tm tim;
+    time_get_local(&tim);
+    char buff[256];
+    strftime(buff, 255, "%x %X", &tim);
+    fprintf(f,"%s: %s (%s)  -- %s\n",buff, contact_name, display_name, status_message);
+    fclose(f);
+  }
+}
+
 static void
 _show_presence_message(PresenceNotifierStatusPlugin* plugin,
 		       OssoABookPresence* presence)
@@ -98,6 +128,7 @@ _show_presence_message(PresenceNotifierStatusPlugin* plugin,
     status_message = osso_abook_presence_get_display_status(presence);
   
   gchar* contact_name = g_strdup_printf("%s",osso_abook_contact_get_name(OSSO_ABOOK_CONTACT(presence)));
+
   /*,
     osso_abook_contact_get_bound_name(OSSO_ABOOK_CONTACT(presence))
   */
@@ -125,8 +156,8 @@ _show_presence_message(PresenceNotifierStatusPlugin* plugin,
 			       G_TYPE_INT,
 			       G_TYPE_INVALID);
     g_object_unref(dbus_proxy);
-    g_free(contact_name);
   }
+  g_free(contact_name);
 }
 
 static void
@@ -175,7 +206,10 @@ _notify_on_change(PresenceNotifierStatusPlugin* plugin,
        prior_status_type != TP_CONNECTION_PRESENCE_TYPE_UNKNOWN
       )
     {
-      _show_presence_message(plugin, presence);
+      if(!plugin->priv->hide_notification)
+	_show_presence_message(plugin, presence);
+      if(plugin->priv->log_notification)
+	_log_presence_message(plugin, presence);
     }
   }
   else
@@ -294,15 +328,28 @@ static void
 _read_notifier_setting(PresenceNotifierStatusPlugin* plugin)
 {
   GConfClient* client = gconf_client_get_default();
+
   if(!GCONF_IS_CLIENT(client))
     return;
   plugin->priv->disabled = gconf_client_get_bool(client, NOTIFIER_DISABLED_GCONF_PATH, NULL);
   plugin->priv->notify_online_status_only = gconf_client_get_bool(client, NOTIFIER_NOTIFY_ONLINE_ONLY_GCONF_PATH, NULL);
   plugin->priv->notify_message_change = gconf_client_get_bool(client, NOTIFIER_NOTIFY_STATUS_MESSAGE_GCONF_PATH, NULL);
   plugin->priv->notification_time_out = gconf_client_get_int(client, NOTIFIER_AUTO_CLOSE_TIME_GCONF_PATH, NULL);
+
   if(gconf_client_get_int(client, NOTIFIER_AUTO_CLOSE_NOTIFICATION_GCONF_PATH, NULL) &&
      plugin->priv->notification_time_out == 0)
     plugin->priv->notification_time_out = 6;
+
+  plugin->priv->hide_notification = gconf_client_get_bool(client, NOTIFIER_HIDE_NOTIFICATION_GCONF_PATH, NULL);
+  plugin->priv->log_notification = gconf_client_get_bool(client, NOTIFIER_LOG_NOTIFICATION_GCONF_PATH, NULL);
+  if(plugin->priv->logfile_path)
+  {
+    g_free(plugin->priv->logfile_path);
+    plugin->priv->logfile_path = NULL;
+  }
+  plugin->priv->logfile_path = gconf_client_get_string(client, NOTIFIER_LOGFILE_PATH_GCONF_PATH, NULL);
+  if(plugin->priv->log_notification && plugin->priv->logfile_path == NULL)
+    plugin->priv->logfile_path = g_strdup("/home/user/MyDocs/presence_notifier.txt");
     
   g_object_unref(client);
 }
@@ -382,6 +429,9 @@ presence_notifier_status_plugin_init(PresenceNotifierStatusPlugin* plugin)
   plugin->priv->dbus_connection = hd_status_plugin_item_get_dbus_g_connection(HD_STATUS_PLUGIN_ITEM(&plugin->parent),
 									      DBUS_BUS_SESSION, 
 									      NULL);
+  plugin->priv->hide_notification = FALSE;
+  plugin->priv->log_notification = FALSE;
+  plugin->priv->logfile_path = NULL;
   plugin->priv->abook_account_manager = osso_abook_account_manager_new();
   EBookQuery* ebook_query = e_book_query_from_string("(not (is_vcard \"X-TELEPATHY-BLOCKED\"  \"yes\"))");
   osso_abook_account_manager_set_roster_query(plugin->priv->abook_account_manager, ebook_query);
