@@ -30,7 +30,9 @@
 #define NOTIFIER_NOTIFY_STATUS_MESSAGE_GCONF_PATH GC_ROOT "/status_message"
 #define NOTIFIER_AUTO_CLOSE_TIME_GCONF_PATH GC_ROOT "/notification_timeout"
 #define NOTIFIER_AUTO_CLOSE_NOTIFICATION_GCONF_PATH GC_ROOT "/auto_notification_close"
-
+#define NOTIFIER_HIDE_NOTIFICATION_GCONF_PATH GC_ROOT "/hide_notification"
+#define NOTIFIER_LOG_NOTIFICATION_GCONF_PATH GC_ROOT "/log_notification"
+#define NOTIFIER_LOGFILE_PATH_GCONF_PATH GC_ROOT "/logfile_path"
 
 static void
 _enable_disable_seconds_box(HildonCheckButton *button,
@@ -38,14 +40,6 @@ _enable_disable_seconds_box(HildonCheckButton *button,
 {
   GtkWidget* box = GTK_WIDGET(user_data);
   gtk_widget_set_sensitive(box, hildon_check_button_get_active(button));
-			   
-/*
-  GConfClient* client = gconf_client_get_default();
-  if(!GCONF_IS_CLIENT(client))
-    return;
-  gconf_client_set_bool(client, NOTIFIER_DISABLED_GCONF_PATH, !hildon_check_button_get_active(button), NULL);
-  g_object_unref(client);
-*/
 }
 
 osso_return_t execute(osso_context_t* osso, gpointer user_data, gboolean user_activated)
@@ -87,7 +81,12 @@ osso_return_t execute(osso_context_t* osso, gpointer user_data, gboolean user_ac
   hildon_gtk_entry_set_input_mode(GTK_ENTRY(seconds_input), HILDON_GTK_INPUT_MODE_NUMERIC);
   GtkWidget* seconds_label = gtk_label_new("seconds");
   GtkWidget* seconds_box = gtk_hbox_new(TRUE, 0);
+  GtkWidget* notification_log_box = gtk_hbox_new(TRUE, 0);
 
+  GtkWidget* notification_check_box = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  GtkWidget* log_check_box = hildon_check_button_new(HILDON_SIZE_FINGER_HEIGHT);
+  gtk_button_set_label(GTK_BUTTON(notification_check_box), "Show notification");
+  gtk_button_set_label(GTK_BUTTON(log_check_box), "Log notification");
 
   gtk_box_pack_start(GTK_BOX(seconds_box), seconds_input, TRUE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(seconds_box), seconds_label, TRUE, FALSE, 0);
@@ -102,7 +101,10 @@ osso_return_t execute(osso_context_t* osso, gpointer user_data, gboolean user_ac
   gtk_box_pack_start(GTK_BOX(content), status_box, FALSE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(content), auto_hide_notification, TRUE, FALSE, 0);
   gtk_box_pack_start(GTK_BOX(content), seconds_box, TRUE, FALSE, 0);
-
+  gtk_box_pack_start(GTK_BOX(content), notification_log_box, TRUE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(notification_log_box), notification_check_box, TRUE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(notification_log_box), log_check_box, TRUE, FALSE, 0);
+  
   gtk_container_add(GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), content);
 
   GConfClient* client = gconf_client_get_default();
@@ -130,6 +132,11 @@ osso_return_t execute(osso_context_t* osso, gpointer user_data, gboolean user_ac
     time_out = 6;
   }
 
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(notification_check_box), 
+				 !gconf_client_get_bool(client, NOTIFIER_HIDE_NOTIFICATION_GCONF_PATH, NULL));
+  hildon_check_button_set_active(HILDON_CHECK_BUTTON(log_check_box), 
+				 gconf_client_get_bool(client, NOTIFIER_LOG_NOTIFICATION_GCONF_PATH, NULL));
+  
   if(!hildon_check_button_get_active(HILDON_CHECK_BUTTON(auto_hide_notification)))
     gtk_widget_set_sensitive(GTK_WIDGET(seconds_box), FALSE);
 
@@ -149,17 +156,22 @@ osso_return_t execute(osso_context_t* osso, gpointer user_data, gboolean user_ac
     gboolean online_only = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(online_only_state_change));
     gboolean message_change = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(status_message_change));
     gboolean auto_hide = hildon_check_button_get_active(HILDON_CHECK_BUTTON(auto_hide_notification));
+    gboolean hide_notification = !hildon_check_button_get_active(HILDON_CHECK_BUTTON(notification_check_box));
+    gboolean log_notification = hildon_check_button_get_active(HILDON_CHECK_BUTTON(log_check_box));
     int time_out = atoi(hildon_entry_get_text(HILDON_ENTRY(seconds_input)));
     GConfClient* client = gconf_client_get_default();
     gconf_client_set_bool(client, NOTIFIER_DISABLED_GCONF_PATH, disable, NULL);
     gconf_client_set_bool(client, NOTIFIER_NOTIFY_ONLINE_ONLY_GCONF_PATH, online_only, NULL);
     gconf_client_set_bool(client, NOTIFIER_NOTIFY_STATUS_MESSAGE_GCONF_PATH, message_change, NULL);
     gconf_client_set_bool(client, NOTIFIER_AUTO_CLOSE_NOTIFICATION_GCONF_PATH, auto_hide, NULL);
+    gconf_client_set_bool(client, NOTIFIER_HIDE_NOTIFICATION_GCONF_PATH, hide_notification, NULL);
+    gconf_client_set_bool(client, NOTIFIER_LOG_NOTIFICATION_GCONF_PATH, log_notification, NULL);
 
     if(auto_hide)
       gconf_client_set_int(client, NOTIFIER_AUTO_CLOSE_TIME_GCONF_PATH, time_out, NULL);
     else
       gconf_client_set_int(client, NOTIFIER_AUTO_CLOSE_TIME_GCONF_PATH, 0, NULL);
+
     g_object_unref(client);
   }
   gtk_widget_destroy(dialog);
